from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.Geom import *
from OCC.Core.gp import *
from OCC.Core.Geom2d import *
from OCC.Core.Extrema import *
from OCC.Core.TColgp import *
from OCC.Core.TColStd import *
from OCC.Core.GeomAbs import *
from OCC.Core.Approx import *


class geomapi:
	@staticmethod
	def To2d(C: Geom_Curve, P: gp_Pln) -> Geom2d_Curve: ...
	@staticmethod
	def To3d(C: Geom2d_Curve, P: gp_Pln) -> Geom_Curve: ...

class GeomAPI_ExtremaCurveCurve:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, C1: Geom_Curve, C2: Geom_Curve) -> None: ...
	@overload
	def __init__(self, C1: Geom_Curve, C2: Geom_Curve, U1min: float, U1max: float, U2min: float, U2max: float) -> None: ...
	def Distance(self, Index: int) -> float: ...
	def Extrema(self) -> Extrema_ExtCC: ...
	@overload
	def Init(self, C1: Geom_Curve, C2: Geom_Curve) -> None: ...
	@overload
	def Init(self, C1: Geom_Curve, C2: Geom_Curve, U1min: float, U1max: float, U2min: float, U2max: float) -> None: ...
	def LowerDistance(self) -> float: ...
	def LowerDistanceParameters(self) -> Tuple[float, float]: ...
	def NbExtrema(self) -> int: ...
	def NearestPoints(self, P1: gp_Pnt, P2: gp_Pnt) -> None: ...
	def Parameters(self, Index: int) -> Tuple[float, float]: ...
	def Points(self, Index: int, P1: gp_Pnt, P2: gp_Pnt) -> None: ...
	def TotalLowerDistance(self) -> float: ...
	def TotalLowerDistanceParameters(self) -> Tuple[bool, float, float]: ...
	def TotalNearestPoints(self, P1: gp_Pnt, P2: gp_Pnt) -> bool: ...

class GeomAPI_ExtremaCurveSurface:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, Curve: Geom_Curve, Surface: Geom_Surface) -> None: ...
	@overload
	def __init__(self, Curve: Geom_Curve, Surface: Geom_Surface, Wmin: float, Wmax: float, Umin: float, Umax: float, Vmin: float, Vmax: float) -> None: ...
	def Distance(self, Index: int) -> float: ...
	def Extrema(self) -> Extrema_ExtCS: ...
	@overload
	def Init(self, Curve: Geom_Curve, Surface: Geom_Surface) -> None: ...
	@overload
	def Init(self, Curve: Geom_Curve, Surface: Geom_Surface, Wmin: float, Wmax: float, Umin: float, Umax: float, Vmin: float, Vmax: float) -> None: ...
	def LowerDistance(self) -> float: ...
	def LowerDistanceParameters(self) -> Tuple[float, float, float]: ...
	def NbExtrema(self) -> int: ...
	def NearestPoints(self, PC: gp_Pnt, PS: gp_Pnt) -> None: ...
	def Parameters(self, Index: int) -> Tuple[float, float, float]: ...
	def Points(self, Index: int, P1: gp_Pnt, P2: gp_Pnt) -> None: ...

class GeomAPI_ExtremaSurfaceSurface:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, S1: Geom_Surface, S2: Geom_Surface) -> None: ...
	@overload
	def __init__(self, S1: Geom_Surface, S2: Geom_Surface, U1min: float, U1max: float, V1min: float, V1max: float, U2min: float, U2max: float, V2min: float, V2max: float) -> None: ...
	def Distance(self, Index: int) -> float: ...
	def Extrema(self) -> Extrema_ExtSS: ...
	@overload
	def Init(self, S1: Geom_Surface, S2: Geom_Surface) -> None: ...
	@overload
	def Init(self, S1: Geom_Surface, S2: Geom_Surface, U1min: float, U1max: float, V1min: float, V1max: float, U2min: float, U2max: float, V2min: float, V2max: float) -> None: ...
	def LowerDistance(self) -> float: ...
	def LowerDistanceParameters(self) -> Tuple[float, float, float, float]: ...
	def NbExtrema(self) -> int: ...
	def NearestPoints(self, P1: gp_Pnt, P2: gp_Pnt) -> None: ...
	def Parameters(self, Index: int) -> Tuple[float, float, float, float]: ...
	def Points(self, Index: int, P1: gp_Pnt, P2: gp_Pnt) -> None: ...

class GeomAPI_IntCS:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, C: Geom_Curve, S: Geom_Surface) -> None: ...
	def IsDone(self) -> bool: ...
	def NbPoints(self) -> int: ...
	def NbSegments(self) -> int: ...
	@overload
	def Parameters(self, Index: int) -> Tuple[float, float, float]: ...
	@overload
	def Parameters(self, Index: int) -> Tuple[float, float, float, float]: ...
	def Perform(self, C: Geom_Curve, S: Geom_Surface) -> None: ...
	def Point(self, Index: int) -> gp_Pnt: ...
	def Segment(self, Index: int) -> Geom_Curve: ...

class GeomAPI_IntSS:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, S1: Geom_Surface, S2: Geom_Surface, Tol: float) -> None: ...
	def IsDone(self) -> bool: ...
	def Line(self, Index: int) -> Geom_Curve: ...
	def NbLines(self) -> int: ...
	def Perform(self, S1: Geom_Surface, S2: Geom_Surface, Tol: float) -> None: ...

class GeomAPI_Interpolate:
	@overload
	def __init__(self, Points: TColgp_HArray1OfPnt, PeriodicFlag: bool, Tolerance: float) -> None: ...
	@overload
	def __init__(self, Points: TColgp_HArray1OfPnt, Parameters: TColStd_HArray1OfReal, PeriodicFlag: bool, Tolerance: float) -> None: ...
	def Curve(self) -> Geom_BSplineCurve: ...
	def IsDone(self) -> bool: ...
	@overload
	def Load(self, InitialTangent: gp_Vec, FinalTangent: gp_Vec, Scale: Optional[bool] = True) -> None: ...
	@overload
	def Load(self, Tangents: TColgp_Array1OfVec, TangentFlags: TColStd_HArray1OfBoolean, Scale: Optional[bool] = True) -> None: ...
	def Perform(self) -> None: ...

class GeomAPI_PointsToBSpline:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, Points: TColgp_Array1OfPnt, DegMin: Optional[int] = 3, DegMax: Optional[int] = 8, Continuity: Optional[GeomAbs_Shape] = GeomAbs_C2, Tol3D: Optional[float] = 1.0e-3) -> None: ...
	@overload
	def __init__(self, Points: TColgp_Array1OfPnt, ParType: Approx_ParametrizationType, DegMin: Optional[int] = 3, DegMax: Optional[int] = 8, Continuity: Optional[GeomAbs_Shape] = GeomAbs_C2, Tol3D: Optional[float] = 1.0e-3) -> None: ...
	@overload
	def __init__(self, Points: TColgp_Array1OfPnt, Parameters: TColStd_Array1OfReal, DegMin: Optional[int] = 3, DegMax: Optional[int] = 8, Continuity: Optional[GeomAbs_Shape] = GeomAbs_C2, Tol3D: Optional[float] = 1.0e-3) -> None: ...
	@overload
	def __init__(self, Points: TColgp_Array1OfPnt, Weight1: float, Weight2: float, Weight3: float, DegMax: Optional[int] = 8, Continuity: Optional[GeomAbs_Shape] = GeomAbs_C2, Tol3D: Optional[float] = 1.0e-3) -> None: ...
	def Curve(self) -> Geom_BSplineCurve: ...
	@overload
	def Init(self, Points: TColgp_Array1OfPnt, DegMin: Optional[int] = 3, DegMax: Optional[int] = 8, Continuity: Optional[GeomAbs_Shape] = GeomAbs_C2, Tol3D: Optional[float] = 1.0e-3) -> None: ...
	@overload
	def Init(self, Points: TColgp_Array1OfPnt, ParType: Approx_ParametrizationType, DegMin: Optional[int] = 3, DegMax: Optional[int] = 8, Continuity: Optional[GeomAbs_Shape] = GeomAbs_C2, Tol3D: Optional[float] = 1.0e-3) -> None: ...
	@overload
	def Init(self, Points: TColgp_Array1OfPnt, Parameters: TColStd_Array1OfReal, DegMin: Optional[int] = 3, DegMax: Optional[int] = 8, Continuity: Optional[GeomAbs_Shape] = GeomAbs_C2, Tol3D: Optional[float] = 1.0e-3) -> None: ...
	@overload
	def Init(self, Points: TColgp_Array1OfPnt, Weight1: float, Weight2: float, Weight3: float, DegMax: Optional[int] = 8, Continuity: Optional[GeomAbs_Shape] = GeomAbs_C2, Tol3D: Optional[float] = 1.0e-3) -> None: ...
	def IsDone(self) -> bool: ...

class GeomAPI_PointsToBSplineSurface:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, Points: TColgp_Array2OfPnt, DegMin: Optional[int] = 3, DegMax: Optional[int] = 8, Continuity: Optional[GeomAbs_Shape] = GeomAbs_C2, Tol3D: Optional[float] = 1.0e-3) -> None: ...
	@overload
	def __init__(self, Points: TColgp_Array2OfPnt, ParType: Approx_ParametrizationType, DegMin: Optional[int] = 3, DegMax: Optional[int] = 8, Continuity: Optional[GeomAbs_Shape] = GeomAbs_C2, Tol3D: Optional[float] = 1.0e-3) -> None: ...
	@overload
	def __init__(self, Points: TColgp_Array2OfPnt, Weight1: float, Weight2: float, Weight3: float, DegMax: Optional[int] = 8, Continuity: Optional[GeomAbs_Shape] = GeomAbs_C2, Tol3D: Optional[float] = 1.0e-3) -> None: ...
	@overload
	def __init__(self, ZPoints: TColStd_Array2OfReal, X0: float, dX: float, Y0: float, dY: float, DegMin: Optional[int] = 3, DegMax: Optional[int] = 8, Continuity: Optional[GeomAbs_Shape] = GeomAbs_C2, Tol3D: Optional[float] = 1.0e-3) -> None: ...
	@overload
	def Init(self, Points: TColgp_Array2OfPnt, DegMin: Optional[int] = 3, DegMax: Optional[int] = 8, Continuity: Optional[GeomAbs_Shape] = GeomAbs_C2, Tol3D: Optional[float] = 1.0e-3) -> None: ...
	@overload
	def Init(self, ZPoints: TColStd_Array2OfReal, X0: float, dX: float, Y0: float, dY: float, DegMin: Optional[int] = 3, DegMax: Optional[int] = 8, Continuity: Optional[GeomAbs_Shape] = GeomAbs_C2, Tol3D: Optional[float] = 1.0e-3) -> None: ...
	@overload
	def Init(self, Points: TColgp_Array2OfPnt, ParType: Approx_ParametrizationType, DegMin: Optional[int] = 3, DegMax: Optional[int] = 8, Continuity: Optional[GeomAbs_Shape] = GeomAbs_C2, Tol3D: Optional[float] = 1.0e-3, thePeriodic: Optional[bool] = False) -> None: ...
	@overload
	def Init(self, Points: TColgp_Array2OfPnt, Weight1: float, Weight2: float, Weight3: float, DegMax: Optional[int] = 8, Continuity: Optional[GeomAbs_Shape] = GeomAbs_C2, Tol3D: Optional[float] = 1.0e-3) -> None: ...
	@overload
	def Interpolate(self, Points: TColgp_Array2OfPnt, thePeriodic: Optional[bool] = False) -> None: ...
	@overload
	def Interpolate(self, Points: TColgp_Array2OfPnt, ParType: Approx_ParametrizationType, thePeriodic: Optional[bool] = False) -> None: ...
	@overload
	def Interpolate(self, ZPoints: TColStd_Array2OfReal, X0: float, dX: float, Y0: float, dY: float) -> None: ...
	def IsDone(self) -> bool: ...
	def Surface(self) -> Geom_BSplineSurface: ...

class GeomAPI_ProjectPointOnCurve:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, P: gp_Pnt, Curve: Geom_Curve) -> None: ...
	@overload
	def __init__(self, P: gp_Pnt, Curve: Geom_Curve, Umin: float, Usup: float) -> None: ...
	def Distance(self, Index: int) -> float: ...
	def Extrema(self) -> Extrema_ExtPC: ...
	@overload
	def Init(self, P: gp_Pnt, Curve: Geom_Curve) -> None: ...
	@overload
	def Init(self, P: gp_Pnt, Curve: Geom_Curve, Umin: float, Usup: float) -> None: ...
	@overload
	def Init(self, Curve: Geom_Curve, Umin: float, Usup: float) -> None: ...
	def LowerDistance(self) -> float: ...
	def LowerDistanceParameter(self) -> float: ...
	def NbPoints(self) -> int: ...
	def NearestPoint(self) -> gp_Pnt: ...
	@overload
	def Parameter(self, Index: int) -> float: ...
	@overload
	def Parameter(self, Index: int) -> float: ...
	def Perform(self, P: gp_Pnt) -> None: ...
	def Point(self, Index: int) -> gp_Pnt: ...

class GeomAPI_ProjectPointOnSurf:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, P: gp_Pnt, Surface: Geom_Surface, Algo: Optional[Extrema_ExtAlgo] = Extrema_ExtAlgo_Grad) -> None: ...
	@overload
	def __init__(self, P: gp_Pnt, Surface: Geom_Surface, Tolerance: float, Algo: Optional[Extrema_ExtAlgo] = Extrema_ExtAlgo_Grad) -> None: ...
	@overload
	def __init__(self, P: gp_Pnt, Surface: Geom_Surface, Umin: float, Usup: float, Vmin: float, Vsup: float, Tolerance: float, Algo: Optional[Extrema_ExtAlgo] = Extrema_ExtAlgo_Grad) -> None: ...
	@overload
	def __init__(self, P: gp_Pnt, Surface: Geom_Surface, Umin: float, Usup: float, Vmin: float, Vsup: float, Algo: Optional[Extrema_ExtAlgo] = Extrema_ExtAlgo_Grad) -> None: ...
	def Distance(self, Index: int) -> float: ...
	def Extrema(self) -> Extrema_ExtPS: ...
	@overload
	def Init(self, P: gp_Pnt, Surface: Geom_Surface, Tolerance: float, Algo: Optional[Extrema_ExtAlgo] = Extrema_ExtAlgo_Grad) -> None: ...
	@overload
	def Init(self, P: gp_Pnt, Surface: Geom_Surface, Algo: Optional[Extrema_ExtAlgo] = Extrema_ExtAlgo_Grad) -> None: ...
	@overload
	def Init(self, P: gp_Pnt, Surface: Geom_Surface, Umin: float, Usup: float, Vmin: float, Vsup: float, Tolerance: float, Algo: Optional[Extrema_ExtAlgo] = Extrema_ExtAlgo_Grad) -> None: ...
	@overload
	def Init(self, P: gp_Pnt, Surface: Geom_Surface, Umin: float, Usup: float, Vmin: float, Vsup: float, Algo: Optional[Extrema_ExtAlgo] = Extrema_ExtAlgo_Grad) -> None: ...
	@overload
	def Init(self, Surface: Geom_Surface, Umin: float, Usup: float, Vmin: float, Vsup: float, Tolerance: float, Algo: Optional[Extrema_ExtAlgo] = Extrema_ExtAlgo_Grad) -> None: ...
	@overload
	def Init(self, Surface: Geom_Surface, Umin: float, Usup: float, Vmin: float, Vsup: float, Algo: Optional[Extrema_ExtAlgo] = Extrema_ExtAlgo_Grad) -> None: ...
	def IsDone(self) -> bool: ...
	def LowerDistance(self) -> float: ...
	def LowerDistanceParameters(self) -> Tuple[float, float]: ...
	def NbPoints(self) -> int: ...
	def NearestPoint(self) -> gp_Pnt: ...
	def Parameters(self, Index: int) -> Tuple[float, float]: ...
	def Perform(self, P: gp_Pnt) -> None: ...
	def Point(self, Index: int) -> gp_Pnt: ...
	def SetExtremaAlgo(self, theAlgo: Extrema_ExtAlgo) -> None: ...
	def SetExtremaFlag(self, theExtFlag: Extrema_ExtFlag) -> None: ...

# harray1 classes
# harray2 classes
# hsequence classes

geomapi_To2d = geomapi.To2d
geomapi_To3d = geomapi.To3d



from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.BRep import *
from OCC.Core.TopoDS import *
from OCC.Core.gp import *
from OCC.Core.Geom import *
from OCC.Core.Geom2d import *


class BRepPrim_Direction(IntEnum):
	BRepPrim_XMin: int = ...
	BRepPrim_XMax: int = ...
	BRepPrim_YMin: int = ...
	BRepPrim_YMax: int = ...
	BRepPrim_ZMin: int = ...
	BRepPrim_ZMax: int = ...
BRepPrim_XMin = BRepPrim_Direction.BRepPrim_XMin
BRepPrim_XMax = BRepPrim_Direction.BRepPrim_XMax
BRepPrim_YMin = BRepPrim_Direction.BRepPrim_YMin
BRepPrim_YMax = BRepPrim_Direction.BRepPrim_YMax
BRepPrim_ZMin = BRepPrim_Direction.BRepPrim_ZMin
BRepPrim_ZMax = BRepPrim_Direction.BRepPrim_ZMax

class BRepPrim_Builder:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, B: BRep_Builder) -> None: ...
	@overload
	def AddEdgeVertex(self, E: TopoDS_Edge, V: TopoDS_Vertex, P: float, direct: bool) -> None: ...
	@overload
	def AddEdgeVertex(self, E: TopoDS_Edge, V: TopoDS_Vertex, P1: float, P2: float) -> None: ...
	def AddFaceWire(self, F: TopoDS_Face, W: TopoDS_Wire) -> None: ...
	def AddShellFace(self, Sh: TopoDS_Shell, F: TopoDS_Face) -> None: ...
	def AddWireEdge(self, W: TopoDS_Wire, E: TopoDS_Edge, direct: bool) -> None: ...
	def Builder(self) -> BRep_Builder: ...
	def CompleteEdge(self, E: TopoDS_Edge) -> None: ...
	def CompleteFace(self, F: TopoDS_Face) -> None: ...
	def CompleteShell(self, S: TopoDS_Shell) -> None: ...
	def CompleteWire(self, W: TopoDS_Wire) -> None: ...
	def MakeDegeneratedEdge(self, E: TopoDS_Edge) -> None: ...
	@overload
	def MakeEdge(self, E: TopoDS_Edge, L: gp_Lin) -> None: ...
	@overload
	def MakeEdge(self, E: TopoDS_Edge, C: gp_Circ) -> None: ...
	def MakeFace(self, F: TopoDS_Face, P: gp_Pln) -> None: ...
	def MakeShell(self, S: TopoDS_Shell) -> None: ...
	def MakeVertex(self, V: TopoDS_Vertex, P: gp_Pnt) -> None: ...
	def MakeWire(self, W: TopoDS_Wire) -> None: ...
	def ReverseFace(self, F: TopoDS_Face) -> None: ...
	@overload
	def SetPCurve(self, E: TopoDS_Edge, F: TopoDS_Face, L: gp_Lin2d) -> None: ...
	@overload
	def SetPCurve(self, E: TopoDS_Edge, F: TopoDS_Face, L1: gp_Lin2d, L2: gp_Lin2d) -> None: ...
	@overload
	def SetPCurve(self, E: TopoDS_Edge, F: TopoDS_Face, C: gp_Circ2d) -> None: ...
	def SetParameters(self, E: TopoDS_Edge, V: TopoDS_Vertex, P1: float, P2: float) -> None: ...

class BRepPrim_FaceBuilder:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, B: BRep_Builder, S: Geom_Surface) -> None: ...
	@overload
	def __init__(self, B: BRep_Builder, S: Geom_Surface, UMin: float, UMax: float, VMin: float, VMax: float) -> None: ...
	def Edge(self, I: int) -> TopoDS_Edge: ...
	def Face(self) -> TopoDS_Face: ...
	@overload
	def Init(self, B: BRep_Builder, S: Geom_Surface) -> None: ...
	@overload
	def Init(self, B: BRep_Builder, S: Geom_Surface, UMin: float, UMax: float, VMin: float, VMax: float) -> None: ...
	def Vertex(self, I: int) -> TopoDS_Vertex: ...

class BRepPrim_GWedge:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, B: BRepPrim_Builder, Axes: gp_Ax2, dx: float, dy: float, dz: float) -> None: ...
	@overload
	def __init__(self, B: BRepPrim_Builder, Axes: gp_Ax2, dx: float, dy: float, dz: float, ltx: float) -> None: ...
	@overload
	def __init__(self, B: BRepPrim_Builder, Axes: gp_Ax2, xmin: float, ymin: float, zmin: float, z2min: float, x2min: float, xmax: float, ymax: float, zmax: float, z2max: float, x2max: float) -> None: ...
	def Axes(self) -> gp_Ax2: ...
	def Close(self, d1: BRepPrim_Direction) -> None: ...
	def Edge(self, d1: BRepPrim_Direction, d2: BRepPrim_Direction) -> TopoDS_Edge: ...
	def Face(self, d1: BRepPrim_Direction) -> TopoDS_Face: ...
	def GetX2Max(self) -> float: ...
	def GetX2Min(self) -> float: ...
	def GetXMax(self) -> float: ...
	def GetXMin(self) -> float: ...
	def GetYMax(self) -> float: ...
	def GetYMin(self) -> float: ...
	def GetZ2Max(self) -> float: ...
	def GetZ2Min(self) -> float: ...
	def GetZMax(self) -> float: ...
	def GetZMin(self) -> float: ...
	def HasEdge(self, d1: BRepPrim_Direction, d2: BRepPrim_Direction) -> bool: ...
	def HasFace(self, d1: BRepPrim_Direction) -> bool: ...
	def HasVertex(self, d1: BRepPrim_Direction, d2: BRepPrim_Direction, d3: BRepPrim_Direction) -> bool: ...
	def HasWire(self, d1: BRepPrim_Direction) -> bool: ...
	def IsDegeneratedShape(self) -> bool: ...
	def IsInfinite(self, d1: BRepPrim_Direction) -> bool: ...
	def Line(self, d1: BRepPrim_Direction, d2: BRepPrim_Direction) -> gp_Lin: ...
	def Open(self, d1: BRepPrim_Direction) -> None: ...
	def Plane(self, d1: BRepPrim_Direction) -> gp_Pln: ...
	def Point(self, d1: BRepPrim_Direction, d2: BRepPrim_Direction, d3: BRepPrim_Direction) -> gp_Pnt: ...
	def Shell(self) -> TopoDS_Shell: ...
	def Vertex(self, d1: BRepPrim_Direction, d2: BRepPrim_Direction, d3: BRepPrim_Direction) -> TopoDS_Vertex: ...
	def Wire(self, d1: BRepPrim_Direction) -> TopoDS_Wire: ...

class BRepPrim_OneAxis:
	@overload
	def Angle(self) -> float: ...
	@overload
	def Angle(self, A: float) -> None: ...
	@overload
	def Axes(self) -> gp_Ax2: ...
	@overload
	def Axes(self, A: gp_Ax2) -> None: ...
	def AxisBottomVertex(self) -> TopoDS_Vertex: ...
	def AxisEdge(self) -> TopoDS_Edge: ...
	def AxisEndWire(self) -> TopoDS_Wire: ...
	def AxisStartWire(self) -> TopoDS_Wire: ...
	def AxisTopVertex(self) -> TopoDS_Vertex: ...
	def BottomEdge(self) -> TopoDS_Edge: ...
	def BottomEndVertex(self) -> TopoDS_Vertex: ...
	def BottomFace(self) -> TopoDS_Face: ...
	def BottomStartVertex(self) -> TopoDS_Vertex: ...
	def BottomWire(self) -> TopoDS_Wire: ...
	def EndBottomEdge(self) -> TopoDS_Edge: ...
	def EndEdge(self) -> TopoDS_Edge: ...
	def EndFace(self) -> TopoDS_Face: ...
	def EndTopEdge(self) -> TopoDS_Edge: ...
	def EndWire(self) -> TopoDS_Wire: ...
	def HasBottom(self) -> bool: ...
	def HasSides(self) -> bool: ...
	def HasTop(self) -> bool: ...
	def LateralEndWire(self) -> TopoDS_Wire: ...
	def LateralFace(self) -> TopoDS_Face: ...
	def LateralStartWire(self) -> TopoDS_Wire: ...
	def LateralWire(self) -> TopoDS_Wire: ...
	def MakeEmptyLateralFace(self) -> TopoDS_Face: ...
	def MakeEmptyMeridianEdge(self, Ang: float) -> TopoDS_Edge: ...
	def MeridianClosed(self) -> bool: ...
	def MeridianOnAxis(self, V: float) -> bool: ...
	def MeridianValue(self, V: float) -> gp_Pnt2d: ...
	def SetMeridianOffset(self, MeridianOffset: Optional[float] = 0) -> None: ...
	def SetMeridianPCurve(self, E: TopoDS_Edge, F: TopoDS_Face) -> None: ...
	def Shell(self) -> TopoDS_Shell: ...
	def StartBottomEdge(self) -> TopoDS_Edge: ...
	def StartEdge(self) -> TopoDS_Edge: ...
	def StartFace(self) -> TopoDS_Face: ...
	def StartTopEdge(self) -> TopoDS_Edge: ...
	def StartWire(self) -> TopoDS_Wire: ...
	def TopEdge(self) -> TopoDS_Edge: ...
	def TopEndVertex(self) -> TopoDS_Vertex: ...
	def TopFace(self) -> TopoDS_Face: ...
	def TopStartVertex(self) -> TopoDS_Vertex: ...
	def TopWire(self) -> TopoDS_Wire: ...
	@overload
	def VMax(self) -> float: ...
	@overload
	def VMax(self, V: float) -> None: ...
	def VMaxInfinite(self) -> bool: ...
	@overload
	def VMin(self) -> float: ...
	@overload
	def VMin(self, V: float) -> None: ...
	def VMinInfinite(self) -> bool: ...

class BRepPrim_Revolution(BRepPrim_OneAxis):
	def __init__(self, A: gp_Ax2, VMin: float, VMax: float, M: Geom_Curve, PM: Geom2d_Curve) -> None: ...
	def MakeEmptyLateralFace(self) -> TopoDS_Face: ...
	def MakeEmptyMeridianEdge(self, Ang: float) -> TopoDS_Edge: ...
	def MeridianValue(self, V: float) -> gp_Pnt2d: ...
	def SetMeridianPCurve(self, E: TopoDS_Edge, F: TopoDS_Face) -> None: ...

class BRepPrim_Wedge(BRepPrim_GWedge):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, Axes: gp_Ax2, dx: float, dy: float, dz: float) -> None: ...
	@overload
	def __init__(self, Axes: gp_Ax2, dx: float, dy: float, dz: float, ltx: float) -> None: ...
	@overload
	def __init__(self, Axes: gp_Ax2, xmin: float, ymin: float, zmin: float, z2min: float, x2min: float, xmax: float, ymax: float, zmax: float, z2max: float, x2max: float) -> None: ...

class BRepPrim_Cone(BRepPrim_Revolution):
	@overload
	def __init__(self, Angle: float, Position: gp_Ax2, Height: float, Radius: Optional[float] = 0) -> None: ...
	@overload
	def __init__(self, Angle: float) -> None: ...
	@overload
	def __init__(self, Angle: float, Apex: gp_Pnt) -> None: ...
	@overload
	def __init__(self, Angle: float, Axes: gp_Ax2) -> None: ...
	@overload
	def __init__(self, R1: float, R2: float, H: float) -> None: ...
	@overload
	def __init__(self, Center: gp_Pnt, R1: float, R2: float, H: float) -> None: ...
	@overload
	def __init__(self, Axes: gp_Ax2, R1: float, R2: float, H: float) -> None: ...
	def MakeEmptyLateralFace(self) -> TopoDS_Face: ...

class BRepPrim_Cylinder(BRepPrim_Revolution):
	@overload
	def __init__(self, Position: gp_Ax2, Radius: float, Height: float) -> None: ...
	@overload
	def __init__(self, Radius: float) -> None: ...
	@overload
	def __init__(self, Center: gp_Pnt, Radius: float) -> None: ...
	@overload
	def __init__(self, Axes: gp_Ax2, Radius: float) -> None: ...
	@overload
	def __init__(self, R: float, H: float) -> None: ...
	@overload
	def __init__(self, Center: gp_Pnt, R: float, H: float) -> None: ...
	def MakeEmptyLateralFace(self) -> TopoDS_Face: ...

class BRepPrim_Sphere(BRepPrim_Revolution):
	@overload
	def __init__(self, Radius: float) -> None: ...
	@overload
	def __init__(self, Center: gp_Pnt, Radius: float) -> None: ...
	@overload
	def __init__(self, Axes: gp_Ax2, Radius: float) -> None: ...
	def MakeEmptyLateralFace(self) -> TopoDS_Face: ...

class BRepPrim_Torus(BRepPrim_Revolution):
	@overload
	def __init__(self, Position: gp_Ax2, Major: float, Minor: float) -> None: ...
	@overload
	def __init__(self, Major: float, Minor: float) -> None: ...
	@overload
	def __init__(self, Center: gp_Pnt, Major: float, Minor: float) -> None: ...
	def MakeEmptyLateralFace(self) -> TopoDS_Face: ...

# harray1 classes
# harray2 classes
# hsequence classes




from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.TCollection import *
from OCC.Core.gp import *
from OCC.Core.TopoDS import *
from OCC.Core.TDocStd import *
from OCC.Core.Bnd import *
from OCC.Core.Quantity import *

#the following typedef cannot be wrapped as is
VrmlData_MapOfNode = NewType('VrmlData_MapOfNode', Any)

class VrmlData_ListOfNode:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Append(self, theItem: False) -> False: ...
    def Prepend(self, theItem: False) -> False: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class VrmlData_ErrorStatus(IntEnum):
	VrmlData_StatusOK: int = ...
	VrmlData_EmptyData: int = ...
	VrmlData_UnrecoverableError: int = ...
	VrmlData_GeneralError: int = ...
	VrmlData_EndOfFile: int = ...
	VrmlData_NotVrmlFile: int = ...
	VrmlData_CannotOpenFile: int = ...
	VrmlData_VrmlFormatError: int = ...
	VrmlData_NumericInputError: int = ...
	VrmlData_IrrelevantNumber: int = ...
	VrmlData_BooleanInputError: int = ...
	VrmlData_StringInputError: int = ...
	VrmlData_NodeNameUnknown: int = ...
	VrmlData_NonPositiveSize: int = ...
	VrmlData_ReadUnknownNode: int = ...
	VrmlData_NonSupportedFeature: int = ...
	VrmlData_OutputStreamUndefined: int = ...
	VrmlData_NotImplemented: int = ...
VrmlData_StatusOK = VrmlData_ErrorStatus.VrmlData_StatusOK
VrmlData_EmptyData = VrmlData_ErrorStatus.VrmlData_EmptyData
VrmlData_UnrecoverableError = VrmlData_ErrorStatus.VrmlData_UnrecoverableError
VrmlData_GeneralError = VrmlData_ErrorStatus.VrmlData_GeneralError
VrmlData_EndOfFile = VrmlData_ErrorStatus.VrmlData_EndOfFile
VrmlData_NotVrmlFile = VrmlData_ErrorStatus.VrmlData_NotVrmlFile
VrmlData_CannotOpenFile = VrmlData_ErrorStatus.VrmlData_CannotOpenFile
VrmlData_VrmlFormatError = VrmlData_ErrorStatus.VrmlData_VrmlFormatError
VrmlData_NumericInputError = VrmlData_ErrorStatus.VrmlData_NumericInputError
VrmlData_IrrelevantNumber = VrmlData_ErrorStatus.VrmlData_IrrelevantNumber
VrmlData_BooleanInputError = VrmlData_ErrorStatus.VrmlData_BooleanInputError
VrmlData_StringInputError = VrmlData_ErrorStatus.VrmlData_StringInputError
VrmlData_NodeNameUnknown = VrmlData_ErrorStatus.VrmlData_NodeNameUnknown
VrmlData_NonPositiveSize = VrmlData_ErrorStatus.VrmlData_NonPositiveSize
VrmlData_ReadUnknownNode = VrmlData_ErrorStatus.VrmlData_ReadUnknownNode
VrmlData_NonSupportedFeature = VrmlData_ErrorStatus.VrmlData_NonSupportedFeature
VrmlData_OutputStreamUndefined = VrmlData_ErrorStatus.VrmlData_OutputStreamUndefined
VrmlData_NotImplemented = VrmlData_ErrorStatus.VrmlData_NotImplemented

class VrmlData_Node(Standard_Transient):
	@staticmethod
	def GlobalIndent() -> int: ...
	def IsDefault(self) -> bool: ...
	def Name(self) -> str: ...
	@overload
	@staticmethod
	def OK(theStat: VrmlData_ErrorStatus) -> bool: ...
	@overload
	@staticmethod
	def OK(outStat: VrmlData_ErrorStatus, theStat: VrmlData_ErrorStatus) -> bool: ...
	def Read(self, theBuffer: VrmlData_InBuffer) -> VrmlData_ErrorStatus: ...
	@staticmethod
	def ReadBoolean(theBuffer: VrmlData_InBuffer) -> Tuple[VrmlData_ErrorStatus, bool]: ...
	def ReadNode(self, theBuffer: VrmlData_InBuffer, theNode: VrmlData_Node, Type: Optional[Standard_Type] = None) -> VrmlData_ErrorStatus: ...
	@staticmethod
	def ReadString(theBuffer: VrmlData_InBuffer, theRes: TCollection_AsciiString) -> VrmlData_ErrorStatus: ...
	def Scene(self) -> VrmlData_Scene: ...
	def Write(self, thePrefix: str) -> VrmlData_ErrorStatus: ...
	def WriteClosing(self) -> VrmlData_ErrorStatus: ...

class VrmlData_Scene:
	def AddNode(self, theN: VrmlData_Node, isTopLevel: Optional[bool] = True) -> VrmlData_Node: ...
	def Allocator(self) -> NCollection_IncAllocator: ...
	@overload
	def FindNode(self, theName: str, theType: Optional[Standard_Type] = 0L) -> VrmlData_Node: ...
	@overload
	def FindNode(self, theName: str, theLocation: gp_Trsf) -> VrmlData_Node: ...
	def GetIterator(self) -> False: ...
	def GetLineError(self) -> int: ...
	def GetShape(self, M: VrmlData_DataMapOfShapeAppearance) -> TopoDS_Shape: ...
	def IsDummyWrite(self) -> bool: ...
	def NamedNodesIterator(self) -> False: ...
	def ReadArrIndex(self, theBuffer: VrmlData_InBuffer, theArr: int, theNBl: int) -> VrmlData_ErrorStatus: ...
	@staticmethod
	def ReadLine(theBuffer: VrmlData_InBuffer) -> VrmlData_ErrorStatus: ...
	def ReadReal(self, theBuffer: VrmlData_InBuffer, isApplyScale: bool, isOnlyPositive: bool) -> Tuple[VrmlData_ErrorStatus, float]: ...
	@staticmethod
	def ReadWord(theBuffer: VrmlData_InBuffer, theStr: TCollection_AsciiString) -> VrmlData_ErrorStatus: ...
	def ReadXY(self, theBuffer: VrmlData_InBuffer, theXYZ: gp_XY, isApplyScale: bool, isOnlyPositive: bool) -> VrmlData_ErrorStatus: ...
	def ReadXYZ(self, theBuffer: VrmlData_InBuffer, theXYZ: gp_XYZ, isApplyScale: bool, isOnlyPositive: bool) -> VrmlData_ErrorStatus: ...
	def SetIndent(self, nSpc: int) -> None: ...
	def SetLinearScale(self, theScale: float) -> None: ...
	def Status(self) -> VrmlData_ErrorStatus: ...
	def VrmlDirIterator(self) -> False: ...
	def WorldInfo(self) -> VrmlData_WorldInfo: ...
	def WriteArrIndex(self, thePrefix: str, theArr: int, theNbBl: int) -> VrmlData_ErrorStatus: ...
	def WriteLine(self, theLine0: str, theLine1: Optional[str] = 0L, theIndent: Optional[int] = 0) -> VrmlData_ErrorStatus: ...
	def WriteXYZ(self, theXYZ: gp_XYZ, isScale: bool, thePostfix: Optional[str] = 0L) -> VrmlData_ErrorStatus: ...

class VrmlData_ShapeConvert:
	def __init__(self, theScene: VrmlData_Scene, theScale: Optional[float] = 1) -> None: ...
	def AddShape(self, theShape: TopoDS_Shape, theName: Optional[str] = 0L) -> None: ...
	def Convert(self, theExtractFaces: bool, theExtractEdges: bool, theDeflection: Optional[float] = 0.01, theDeflAngle: Optional[float] = 20*M_PI/180) -> None: ...
	def ConvertDocument(self, theDoc: TDocStd_Document) -> None: ...

class VrmlData_Appearance(VrmlData_Node):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, theScene: VrmlData_Scene, theName: str) -> None: ...
	def IsDefault(self) -> bool: ...
	def Material(self) -> VrmlData_Material: ...
	def Read(self, theBuffer: VrmlData_InBuffer) -> VrmlData_ErrorStatus: ...
	def SetMaterial(self, theMat: VrmlData_Material) -> None: ...
	def SetTexture(self, theTexture: VrmlData_Texture) -> None: ...
	def SetTextureTransform(self, theTT: VrmlData_TextureTransform) -> None: ...
	def Texture(self) -> VrmlData_Texture: ...
	def TextureTransform(self) -> VrmlData_TextureTransform: ...
	def Write(self, thePrefix: str) -> VrmlData_ErrorStatus: ...

class VrmlData_Geometry(VrmlData_Node):
	def TShape(self) -> TopoDS_TShape: ...

class VrmlData_Group(VrmlData_Node):
	@overload
	def __init__(self, isTransform: Optional[bool] = False) -> None: ...
	@overload
	def __init__(self, theScene: VrmlData_Scene, theName: str, isTransform: Optional[bool] = False) -> None: ...
	def AddNode(self, theNode: VrmlData_Node) -> VrmlData_Node: ...
	def Box(self) -> Bnd_B3f: ...
	def Clone(self, theOther: VrmlData_Node) -> VrmlData_Node: ...
	def FindNode(self, theName: str, theLocation: gp_Trsf) -> VrmlData_Node: ...
	def GetTransform(self) -> gp_Trsf: ...
	def IsTransform(self) -> bool: ...
	def NodeIterator(self) -> False: ...
	def Read(self, theBuffer: VrmlData_InBuffer) -> VrmlData_ErrorStatus: ...
	def RemoveNode(self, theNode: VrmlData_Node) -> bool: ...
	def SetBox(self, theBox: Bnd_B3f) -> None: ...
	def SetTransform(self, theTrsf: gp_Trsf) -> bool: ...
	def Shape(self, theShape: TopoDS_Shape, pMapApp: VrmlData_DataMapOfShapeAppearance) -> None: ...
	def Write(self, thePrefix: str) -> VrmlData_ErrorStatus: ...

class VrmlData_Material(VrmlData_Node):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, theScene: VrmlData_Scene, theName: str, theAmbientIntensity: Optional[float] = -1, theShininess: Optional[float] = -1, theTransparency: Optional[float] = -1) -> None: ...
	def AmbientIntensity(self) -> float: ...
	def Clone(self, theOther: VrmlData_Node) -> VrmlData_Node: ...
	def DiffuseColor(self) -> Quantity_Color: ...
	def EmissiveColor(self) -> Quantity_Color: ...
	def IsDefault(self) -> bool: ...
	def Read(self, theBuffer: VrmlData_InBuffer) -> VrmlData_ErrorStatus: ...
	def SetAmbientIntensity(self, theAmbientIntensity: float) -> None: ...
	def SetDiffuseColor(self, theColor: Quantity_Color) -> None: ...
	def SetEmissiveColor(self, theColor: Quantity_Color) -> None: ...
	def SetShininess(self, theShininess: float) -> None: ...
	def SetSpecularColor(self, theColor: Quantity_Color) -> None: ...
	def SetTransparency(self, theTransparency: float) -> None: ...
	def Shininess(self) -> float: ...
	def SpecularColor(self) -> Quantity_Color: ...
	def Transparency(self) -> float: ...
	def Write(self, thePrefix: str) -> VrmlData_ErrorStatus: ...

class VrmlData_ShapeNode(VrmlData_Node):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, theScene: VrmlData_Scene, theName: str) -> None: ...
	def Appearance(self) -> VrmlData_Appearance: ...
	def Clone(self, theOther: VrmlData_Node) -> VrmlData_Node: ...
	def Geometry(self) -> VrmlData_Geometry: ...
	def IsDefault(self) -> bool: ...
	def Read(self, theBuffer: VrmlData_InBuffer) -> VrmlData_ErrorStatus: ...
	def SetAppearance(self, theAppear: VrmlData_Appearance) -> None: ...
	def SetGeometry(self, theGeometry: VrmlData_Geometry) -> None: ...
	def Write(self, thePrefix: str) -> VrmlData_ErrorStatus: ...

class VrmlData_TextureCoordinate(VrmlData_Node):
	@overload
	def __init__(self) -> None: ...
	def AllocateValues(self, theLength: int) -> bool: ...
	def Clone(self, theOther: VrmlData_Node) -> VrmlData_Node: ...
	def Length(self) -> False: ...
	def Points(self) -> gp_XY: ...
	def Read(self, theBuffer: VrmlData_InBuffer) -> VrmlData_ErrorStatus: ...

class VrmlData_UnknownNode(VrmlData_Node):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, theScene: VrmlData_Scene, theName: Optional[str] = 0L, theTitle: Optional[str] = 0L) -> None: ...
	def GetTitle(self) -> TCollection_AsciiString: ...
	def IsDefault(self) -> bool: ...
	def Read(self, theBuffer: VrmlData_InBuffer) -> VrmlData_ErrorStatus: ...

class VrmlData_WorldInfo(VrmlData_Node):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, theScene: VrmlData_Scene, theName: Optional[str] = 0L, theTitle: Optional[str] = 0L) -> None: ...
	def AddInfo(self, theString: str) -> None: ...
	def Clone(self, theOther: VrmlData_Node) -> VrmlData_Node: ...
	def InfoIterator(self) -> str: ...
	def IsDefault(self) -> bool: ...
	def Read(self, theBuffer: VrmlData_InBuffer) -> VrmlData_ErrorStatus: ...
	def SetTitle(self, theString: str) -> None: ...
	def Title(self) -> str: ...
	def Write(self, thePrefix: str) -> VrmlData_ErrorStatus: ...

class VrmlData_Box(VrmlData_Geometry):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, theScene: VrmlData_Scene, theName: str, sizeX: Optional[float] = 2, sizeY: Optional[float] = 2, sizeZ: Optional[float] = 2) -> None: ...
	def Clone(self, theOther: VrmlData_Node) -> VrmlData_Node: ...
	def Read(self, theBuffer: VrmlData_InBuffer) -> VrmlData_ErrorStatus: ...
	def SetSize(self, theSize: gp_XYZ) -> None: ...
	def Size(self) -> gp_XYZ: ...
	def TShape(self) -> TopoDS_TShape: ...
	def Write(self, thePrefix: str) -> VrmlData_ErrorStatus: ...

class VrmlData_Color(VrmlData_ArrayVec3d):
	@overload
	def __init__(self) -> None: ...
	def Clone(self, theOther: VrmlData_Node) -> VrmlData_Node: ...
	def Color(self, i: int) -> Quantity_Color: ...
	def Read(self, theBuffer: VrmlData_InBuffer) -> VrmlData_ErrorStatus: ...
	def Write(self, thePrefix: str) -> VrmlData_ErrorStatus: ...

class VrmlData_Cone(VrmlData_Geometry):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, theScene: VrmlData_Scene, theName: str, theBottomRadius: Optional[float] = 1, theHeight: Optional[float] = 2) -> None: ...
	def BottomRadius(self) -> float: ...
	def Clone(self, theOther: VrmlData_Node) -> VrmlData_Node: ...
	def HasBottom(self) -> bool: ...
	def HasSide(self) -> bool: ...
	def Height(self) -> float: ...
	def Read(self, theBuffer: VrmlData_InBuffer) -> VrmlData_ErrorStatus: ...
	def SetBottomRadius(self, theRadius: float) -> None: ...
	def SetFaces(self, hasBottom: bool, hasSide: bool) -> None: ...
	def SetHeight(self, theHeight: float) -> None: ...
	def TShape(self) -> TopoDS_TShape: ...
	def Write(self, thePrefix: str) -> VrmlData_ErrorStatus: ...

class VrmlData_Coordinate(VrmlData_ArrayVec3d):
	@overload
	def __init__(self) -> None: ...
	def Clone(self, theOther: VrmlData_Node) -> VrmlData_Node: ...
	def Coordinate(self, i: int) -> gp_XYZ: ...
	def Read(self, theBuffer: VrmlData_InBuffer) -> VrmlData_ErrorStatus: ...
	def Write(self, thePrefix: str) -> VrmlData_ErrorStatus: ...

class VrmlData_Cylinder(VrmlData_Geometry):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, theScene: VrmlData_Scene, theName: str, theRadius: Optional[float] = 1, theHeight: Optional[float] = 2) -> None: ...
	def Clone(self, theOther: VrmlData_Node) -> VrmlData_Node: ...
	def HasBottom(self) -> bool: ...
	def HasSide(self) -> bool: ...
	def HasTop(self) -> bool: ...
	def Height(self) -> float: ...
	def Radius(self) -> float: ...
	def Read(self, theBuffer: VrmlData_InBuffer) -> VrmlData_ErrorStatus: ...
	def SetFaces(self, hasBottom: bool, hasSide: bool, hasTop: bool) -> None: ...
	def SetHeight(self, theHeight: float) -> None: ...
	def SetRadius(self, theRadius: float) -> None: ...
	def TShape(self) -> TopoDS_TShape: ...
	def Write(self, thePrefix: str) -> VrmlData_ErrorStatus: ...

class VrmlData_ImageTexture(VrmlData_Texture):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, theScene: VrmlData_Scene, theName: str, theURL: Optional[str] = 0L, theRepS: Optional[bool] = False, theRepT: Optional[bool] = False) -> None: ...
	def Clone(self, theOther: VrmlData_Node) -> VrmlData_Node: ...
	def Read(self, theBuffer: VrmlData_InBuffer) -> VrmlData_ErrorStatus: ...
	def URL(self) -> False: ...
	def Write(self, thePrefix: str) -> VrmlData_ErrorStatus: ...

class VrmlData_IndexedLineSet(VrmlData_Geometry):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, theScene: VrmlData_Scene, theName: str, isColorPerVertex: Optional[bool] = True) -> None: ...
	def ArrayColorInd(self, arrColorInd: int) -> False: ...
	def Clone(self, theOther: VrmlData_Node) -> VrmlData_Node: ...
	def Colors(self) -> VrmlData_Color: ...
	def Coordinates(self) -> VrmlData_Coordinate: ...
	def GetColor(self, iFace: int, iVertex: int) -> Quantity_Color: ...
	def IsDefault(self) -> bool: ...
	def Polygon(self, iPolygon: int, outIndice: int) -> int: ...
	def Polygons(self, arrPolygons: int) -> False: ...
	def Read(self, theBuffer: VrmlData_InBuffer) -> VrmlData_ErrorStatus: ...
	def SetColorInd(self, nIndice: int, theIndice: int) -> None: ...
	def SetColorPerVertex(self, isColorPerVertex: bool) -> None: ...
	def SetColors(self, theColors: VrmlData_Color) -> None: ...
	def SetCoordinates(self, theCoord: VrmlData_Coordinate) -> None: ...
	def SetPolygons(self, nPolygons: int, thePolygons: int) -> None: ...
	def TShape(self) -> TopoDS_TShape: ...
	def Write(self, thePrefix: str) -> VrmlData_ErrorStatus: ...

class VrmlData_Normal(VrmlData_ArrayVec3d):
	@overload
	def __init__(self) -> None: ...
	def Clone(self, theOther: VrmlData_Node) -> VrmlData_Node: ...
	def Normal(self, i: int) -> gp_XYZ: ...
	def Read(self, theBuffer: VrmlData_InBuffer) -> VrmlData_ErrorStatus: ...
	def Write(self, thePrefix: str) -> VrmlData_ErrorStatus: ...

class VrmlData_Sphere(VrmlData_Geometry):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, theScene: VrmlData_Scene, theName: str, theRadius: Optional[float] = 1) -> None: ...
	def Clone(self, theOther: VrmlData_Node) -> VrmlData_Node: ...
	def Radius(self) -> float: ...
	def Read(self, theBuffer: VrmlData_InBuffer) -> VrmlData_ErrorStatus: ...
	def SetRadius(self, theRadius: float) -> None: ...
	def TShape(self) -> TopoDS_TShape: ...
	def Write(self, thePrefix: str) -> VrmlData_ErrorStatus: ...

class VrmlData_IndexedFaceSet(VrmlData_Faceted):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, theScene: VrmlData_Scene, theName: str, isCCW: Optional[bool] = True, isSolid: Optional[bool] = True, isConvex: Optional[bool] = True, theCreaseAngle: Optional[float] = 0) -> None: ...
	def ArrayColorInd(self, arrColorInd: int) -> False: ...
	def ArrayNormalInd(self, arrNormalInd: int) -> False: ...
	def ArrayTextureCoordInd(self, arrTextureCoordInd: int) -> False: ...
	def Clone(self, theOther: VrmlData_Node) -> VrmlData_Node: ...
	def Colors(self) -> VrmlData_Color: ...
	def Coordinates(self) -> VrmlData_Coordinate: ...
	def GetColor(self, iFace: int, iVertex: int) -> Quantity_Color: ...
	def IndiceNormals(self, iFace: int, outIndice: int) -> int: ...
	def IsDefault(self) -> bool: ...
	def Normals(self) -> VrmlData_Normal: ...
	def Polygon(self, iFace: int, outIndice: int) -> int: ...
	def Polygons(self, arrPolygons: int) -> False: ...
	def Read(self, theBuffer: VrmlData_InBuffer) -> VrmlData_ErrorStatus: ...
	def SetColorInd(self, nIndice: int, theIndice: int) -> None: ...
	def SetColorPerVertex(self, isColorPerVertex: bool) -> None: ...
	def SetColors(self, theColors: VrmlData_Color) -> None: ...
	def SetCoordinates(self, theCoord: VrmlData_Coordinate) -> None: ...
	def SetNormalInd(self, nIndice: int, theIndice: int) -> None: ...
	def SetNormalPerVertex(self, isNormalPerVertex: bool) -> None: ...
	def SetNormals(self, theNormals: VrmlData_Normal) -> None: ...
	def SetPolygons(self, nPolygons: int, thePolygons: int) -> None: ...
	def SetTextureCoordInd(self, nIndice: int, theIndice: int) -> None: ...
	def SetTextureCoords(self, tc: VrmlData_TextureCoordinate) -> None: ...
	def TShape(self) -> TopoDS_TShape: ...
	def TextureCoords(self) -> VrmlData_TextureCoordinate: ...
	def Write(self, thePrefix: str) -> VrmlData_ErrorStatus: ...

#classnotwrapped
class VrmlData_InBuffer: ...

#classnotwrapped
class VrmlData_ArrayVec3d: ...

#classnotwrapped
class VrmlData_Texture: ...

#classnotwrapped
class VrmlData_TextureTransform: ...

#classnotwrapped
class VrmlData_Faceted: ...

# harray1 classes
# harray2 classes
# hsequence classes

VrmlData_Node_GlobalIndent = VrmlData_Node.GlobalIndent
VrmlData_Node_OK = VrmlData_Node.OK
VrmlData_Node_OK = VrmlData_Node.OK
VrmlData_Node_ReadBoolean = VrmlData_Node.ReadBoolean
VrmlData_Node_ReadInteger = VrmlData_Node.ReadInteger
VrmlData_Node_ReadMultiString = VrmlData_Node.ReadMultiString
VrmlData_Node_ReadString = VrmlData_Node.ReadString
VrmlData_Scene_ReadLine = VrmlData_Scene.ReadLine
VrmlData_Scene_ReadWord = VrmlData_Scene.ReadWord



from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.gp import *
from OCC.Core.TColStd import *


class IntAna_ListOfCurve:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> IntAna_Curve: ...
    def Last(self) -> IntAna_Curve: ...
    def Append(self, theItem: IntAna_Curve) -> IntAna_Curve: ...
    def Prepend(self, theItem: IntAna_Curve) -> IntAna_Curve: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> IntAna_Curve: ...
    def SetValue(self, theIndex: int, theValue: IntAna_Curve) -> None: ...

class IntAna_ResultType(IntEnum):
	IntAna_Point: int = ...
	IntAna_Line: int = ...
	IntAna_Circle: int = ...
	IntAna_PointAndCircle: int = ...
	IntAna_Ellipse: int = ...
	IntAna_Parabola: int = ...
	IntAna_Hyperbola: int = ...
	IntAna_Empty: int = ...
	IntAna_Same: int = ...
	IntAna_NoGeometricSolution: int = ...
IntAna_Point = IntAna_ResultType.IntAna_Point
IntAna_Line = IntAna_ResultType.IntAna_Line
IntAna_Circle = IntAna_ResultType.IntAna_Circle
IntAna_PointAndCircle = IntAna_ResultType.IntAna_PointAndCircle
IntAna_Ellipse = IntAna_ResultType.IntAna_Ellipse
IntAna_Parabola = IntAna_ResultType.IntAna_Parabola
IntAna_Hyperbola = IntAna_ResultType.IntAna_Hyperbola
IntAna_Empty = IntAna_ResultType.IntAna_Empty
IntAna_Same = IntAna_ResultType.IntAna_Same
IntAna_NoGeometricSolution = IntAna_ResultType.IntAna_NoGeometricSolution

class IntAna_Curve:
	def __init__(self) -> None: ...
	def D1u(self, Theta: float, P: gp_Pnt, V: gp_Vec) -> bool: ...
	def Domain(self) -> Tuple[float, float]: ...
	def FindParameter(self, P: gp_Pnt, theParams: TColStd_ListOfReal) -> None: ...
	def IsConstant(self) -> bool: ...
	def IsFirstOpen(self) -> bool: ...
	def IsLastOpen(self) -> bool: ...
	def IsOpen(self) -> bool: ...
	def SetConeQuadValues(self, Cone: gp_Cone, Qxx: float, Qyy: float, Qzz: float, Qxy: float, Qxz: float, Qyz: float, Qx: float, Qy: float, Qz: float, Q1: float, Tol: float, DomInf: float, DomSup: float, TwoZForATheta: bool, ZIsPositive: bool) -> None: ...
	def SetCylinderQuadValues(self, Cylinder: gp_Cylinder, Qxx: float, Qyy: float, Qzz: float, Qxy: float, Qxz: float, Qyz: float, Qx: float, Qy: float, Qz: float, Q1: float, Tol: float, DomInf: float, DomSup: float, TwoZForATheta: bool, ZIsPositive: bool) -> None: ...
	def SetDomain(self, theFirst: float, theLast: float) -> None: ...
	def SetIsFirstOpen(self, Flag: bool) -> None: ...
	def SetIsLastOpen(self, Flag: bool) -> None: ...
	def Value(self, Theta: float) -> gp_Pnt: ...

class IntAna_Int3Pln:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, P1: gp_Pln, P2: gp_Pln, P3: gp_Pln) -> None: ...
	def IsDone(self) -> bool: ...
	def IsEmpty(self) -> bool: ...
	def Perform(self, P1: gp_Pln, P2: gp_Pln, P3: gp_Pln) -> None: ...
	def Value(self) -> gp_Pnt: ...

class IntAna_IntConicQuad:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, L: gp_Lin, Q: IntAna_Quadric) -> None: ...
	@overload
	def __init__(self, C: gp_Circ, Q: IntAna_Quadric) -> None: ...
	@overload
	def __init__(self, E: gp_Elips, Q: IntAna_Quadric) -> None: ...
	@overload
	def __init__(self, P: gp_Parab, Q: IntAna_Quadric) -> None: ...
	@overload
	def __init__(self, H: gp_Hypr, Q: IntAna_Quadric) -> None: ...
	@overload
	def __init__(self, L: gp_Lin, P: gp_Pln, Tolang: float, Tol: Optional[float] = 0, Len: Optional[float] = 0) -> None: ...
	@overload
	def __init__(self, C: gp_Circ, P: gp_Pln, Tolang: float, Tol: float) -> None: ...
	@overload
	def __init__(self, E: gp_Elips, P: gp_Pln, Tolang: float, Tol: float) -> None: ...
	@overload
	def __init__(self, Pb: gp_Parab, P: gp_Pln, Tolang: float) -> None: ...
	@overload
	def __init__(self, H: gp_Hypr, P: gp_Pln, Tolang: float) -> None: ...
	def IsDone(self) -> bool: ...
	def IsInQuadric(self) -> bool: ...
	def IsParallel(self) -> bool: ...
	def NbPoints(self) -> int: ...
	def ParamOnConic(self, N: int) -> float: ...
	@overload
	def Perform(self, L: gp_Lin, Q: IntAna_Quadric) -> None: ...
	@overload
	def Perform(self, C: gp_Circ, Q: IntAna_Quadric) -> None: ...
	@overload
	def Perform(self, E: gp_Elips, Q: IntAna_Quadric) -> None: ...
	@overload
	def Perform(self, P: gp_Parab, Q: IntAna_Quadric) -> None: ...
	@overload
	def Perform(self, H: gp_Hypr, Q: IntAna_Quadric) -> None: ...
	@overload
	def Perform(self, L: gp_Lin, P: gp_Pln, Tolang: float, Tol: Optional[float] = 0, Len: Optional[float] = 0) -> None: ...
	@overload
	def Perform(self, C: gp_Circ, P: gp_Pln, Tolang: float, Tol: float) -> None: ...
	@overload
	def Perform(self, E: gp_Elips, P: gp_Pln, Tolang: float, Tol: float) -> None: ...
	@overload
	def Perform(self, Pb: gp_Parab, P: gp_Pln, Tolang: float) -> None: ...
	@overload
	def Perform(self, H: gp_Hypr, P: gp_Pln, Tolang: float) -> None: ...
	def Point(self, N: int) -> gp_Pnt: ...

class IntAna_IntLinTorus:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, L: gp_Lin, T: gp_Torus) -> None: ...
	def IsDone(self) -> bool: ...
	def NbPoints(self) -> int: ...
	def ParamOnLine(self, Index: int) -> float: ...
	def ParamOnTorus(self, Index: int) -> Tuple[float, float]: ...
	def Perform(self, L: gp_Lin, T: gp_Torus) -> None: ...
	def Value(self, Index: int) -> gp_Pnt: ...

class IntAna_IntQuadQuad:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, C: gp_Cylinder, Q: IntAna_Quadric, Tol: float) -> None: ...
	@overload
	def __init__(self, C: gp_Cone, Q: IntAna_Quadric, Tol: float) -> None: ...
	def Curve(self, N: int) -> IntAna_Curve: ...
	def HasNextCurve(self, I: int) -> bool: ...
	def HasPreviousCurve(self, I: int) -> bool: ...
	def IdenticalElements(self) -> bool: ...
	def IsDone(self) -> bool: ...
	def NbCurve(self) -> int: ...
	def NbPnt(self) -> int: ...
	def NextCurve(self, I: int) -> Tuple[int, bool]: ...
	def Parameters(self, N: int) -> Tuple[float, float]: ...
	@overload
	def Perform(self, C: gp_Cylinder, Q: IntAna_Quadric, Tol: float) -> None: ...
	@overload
	def Perform(self, C: gp_Cone, Q: IntAna_Quadric, Tol: float) -> None: ...
	def Point(self, N: int) -> gp_Pnt: ...
	def PreviousCurve(self, I: int) -> Tuple[int, bool]: ...

class IntAna_QuadQuadGeo:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, P1: gp_Pln, P2: gp_Pln, TolAng: float, Tol: float) -> None: ...
	@overload
	def __init__(self, P: gp_Pln, C: gp_Cylinder, Tolang: float, Tol: float, H: Optional[float] = 0) -> None: ...
	@overload
	def __init__(self, P: gp_Pln, S: gp_Sphere) -> None: ...
	@overload
	def __init__(self, P: gp_Pln, C: gp_Cone, Tolang: float, Tol: float) -> None: ...
	@overload
	def __init__(self, Cyl1: gp_Cylinder, Cyl2: gp_Cylinder, Tol: float) -> None: ...
	@overload
	def __init__(self, Cyl: gp_Cylinder, Sph: gp_Sphere, Tol: float) -> None: ...
	@overload
	def __init__(self, Cyl: gp_Cylinder, Con: gp_Cone, Tol: float) -> None: ...
	@overload
	def __init__(self, Sph1: gp_Sphere, Sph2: gp_Sphere, Tol: float) -> None: ...
	@overload
	def __init__(self, Sph: gp_Sphere, Con: gp_Cone, Tol: float) -> None: ...
	@overload
	def __init__(self, Con1: gp_Cone, Con2: gp_Cone, Tol: float) -> None: ...
	@overload
	def __init__(self, Pln: gp_Pln, Tor: gp_Torus, Tol: float) -> None: ...
	@overload
	def __init__(self, Cyl: gp_Cylinder, Tor: gp_Torus, Tol: float) -> None: ...
	@overload
	def __init__(self, Con: gp_Cone, Tor: gp_Torus, Tol: float) -> None: ...
	@overload
	def __init__(self, Sph: gp_Sphere, Tor: gp_Torus, Tol: float) -> None: ...
	@overload
	def __init__(self, Tor1: gp_Torus, Tor2: gp_Torus, Tol: float) -> None: ...
	def Circle(self, Num: int) -> gp_Circ: ...
	def Ellipse(self, Num: int) -> gp_Elips: ...
	def HasCommonGen(self) -> bool: ...
	def Hyperbola(self, Num: int) -> gp_Hypr: ...
	def IsDone(self) -> bool: ...
	def Line(self, Num: int) -> gp_Lin: ...
	def NbSolutions(self) -> int: ...
	def PChar(self) -> gp_Pnt: ...
	def Parabola(self, Num: int) -> gp_Parab: ...
	@overload
	def Perform(self, P1: gp_Pln, P2: gp_Pln, TolAng: float, Tol: float) -> None: ...
	@overload
	def Perform(self, P: gp_Pln, C: gp_Cylinder, Tolang: float, Tol: float, H: Optional[float] = 0) -> None: ...
	@overload
	def Perform(self, P: gp_Pln, S: gp_Sphere) -> None: ...
	@overload
	def Perform(self, P: gp_Pln, C: gp_Cone, Tolang: float, Tol: float) -> None: ...
	@overload
	def Perform(self, Cyl1: gp_Cylinder, Cyl2: gp_Cylinder, Tol: float) -> None: ...
	@overload
	def Perform(self, Cyl: gp_Cylinder, Sph: gp_Sphere, Tol: float) -> None: ...
	@overload
	def Perform(self, Cyl: gp_Cylinder, Con: gp_Cone, Tol: float) -> None: ...
	@overload
	def Perform(self, Sph1: gp_Sphere, Sph2: gp_Sphere, Tol: float) -> None: ...
	@overload
	def Perform(self, Sph: gp_Sphere, Con: gp_Cone, Tol: float) -> None: ...
	@overload
	def Perform(self, Con1: gp_Cone, Con2: gp_Cone, Tol: float) -> None: ...
	@overload
	def Perform(self, Pln: gp_Pln, Tor: gp_Torus, Tol: float) -> None: ...
	@overload
	def Perform(self, Cyl: gp_Cylinder, Tor: gp_Torus, Tol: float) -> None: ...
	@overload
	def Perform(self, Con: gp_Cone, Tor: gp_Torus, Tol: float) -> None: ...
	@overload
	def Perform(self, Sph: gp_Sphere, Tor: gp_Torus, Tol: float) -> None: ...
	@overload
	def Perform(self, Tor1: gp_Torus, Tor2: gp_Torus, Tol: float) -> None: ...
	def Point(self, Num: int) -> gp_Pnt: ...
	def TypeInter(self) -> IntAna_ResultType: ...

class IntAna_Quadric:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, P: gp_Pln) -> None: ...
	@overload
	def __init__(self, Sph: gp_Sphere) -> None: ...
	@overload
	def __init__(self, Cyl: gp_Cylinder) -> None: ...
	@overload
	def __init__(self, Cone: gp_Cone) -> None: ...
	def Coefficients(self) -> Tuple[float, float, float, float, float, float, float, float, float, float]: ...
	def NewCoefficients(self, Axis: gp_Ax3) -> Tuple[float, float, float, float, float, float, float, float, float, float]: ...
	@overload
	def SetQuadric(self, P: gp_Pln) -> None: ...
	@overload
	def SetQuadric(self, Sph: gp_Sphere) -> None: ...
	@overload
	def SetQuadric(self, Con: gp_Cone) -> None: ...
	@overload
	def SetQuadric(self, Cyl: gp_Cylinder) -> None: ...
	def SpecialPoints(self) -> False: ...

# harray1 classes
# harray2 classes
# hsequence classes




# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
IntWalk module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_intwalk.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _IntWalk
else:
    import _IntWalk

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _IntWalk.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _IntWalk.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _IntWalk.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _IntWalk.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _IntWalk.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _IntWalk.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _IntWalk.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _IntWalk.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _IntWalk.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _IntWalk.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _IntWalk.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _IntWalk.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _IntWalk.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _IntWalk.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _IntWalk.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _IntWalk.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _IntWalk.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _IntWalk:
_IntWalk.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _IntWalk.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.math
import OCC.Core.TColStd
import OCC.Core.TCollection
import OCC.Core.Message
import OCC.Core.OSD
import OCC.Core.gp
import OCC.Core.Adaptor3d
import OCC.Core.Geom
import OCC.Core.GeomAbs
import OCC.Core.TColgp
import OCC.Core.TopAbs
import OCC.Core.Adaptor2d
import OCC.Core.Geom2d
import OCC.Core.IntImp
import OCC.Core.IntSurf

from enum import IntEnum
from OCC.Core.Exception import *

IntWalk_PasTropGrand = _IntWalk.IntWalk_PasTropGrand
IntWalk_StepTooSmall = _IntWalk.IntWalk_StepTooSmall
IntWalk_PointConfondu = _IntWalk.IntWalk_PointConfondu
IntWalk_ArretSurPointPrecedent = _IntWalk.IntWalk_ArretSurPointPrecedent
IntWalk_ArretSurPoint = _IntWalk.IntWalk_ArretSurPoint
IntWalk_OK = _IntWalk.IntWalk_OK


class IntWalk_StatusDeflection(IntEnum):
	IntWalk_PasTropGrand = 0
	IntWalk_StepTooSmall = 1
	IntWalk_PointConfondu = 2
	IntWalk_ArretSurPointPrecedent = 3
	IntWalk_ArretSurPoint = 4
	IntWalk_OK = 5
IntWalk_PasTropGrand = IntWalk_StatusDeflection.IntWalk_PasTropGrand
IntWalk_StepTooSmall = IntWalk_StatusDeflection.IntWalk_StepTooSmall
IntWalk_PointConfondu = IntWalk_StatusDeflection.IntWalk_PointConfondu
IntWalk_ArretSurPointPrecedent = IntWalk_StatusDeflection.IntWalk_ArretSurPointPrecedent
IntWalk_ArretSurPoint = IntWalk_StatusDeflection.IntWalk_ArretSurPoint
IntWalk_OK = IntWalk_StatusDeflection.IntWalk_OK

class IntWalk_TheFunctionOfTheInt2S(OCC.Core.math.math_FunctionSetWithDerivatives):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        S1: Adaptor3d_HSurface
        S2: Adaptor3d_HSurface

        Returns
        -------
        None

        """
        _IntWalk.IntWalk_TheFunctionOfTheInt2S_swiginit(self, _IntWalk.new_IntWalk_TheFunctionOfTheInt2S(*args))

    def AuxillarSurface1(self, *args) -> "opencascade::handle< Adaptor3d_HSurface > const &":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<Adaptor3d_HSurface>

        """
        return _IntWalk.IntWalk_TheFunctionOfTheInt2S_AuxillarSurface1(self, *args)

    def AuxillarSurface2(self, *args) -> "opencascade::handle< Adaptor3d_HSurface > const &":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<Adaptor3d_HSurface>

        """
        return _IntWalk.IntWalk_TheFunctionOfTheInt2S_AuxillarSurface2(self, *args)

    def ComputeParameters(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ChoixIso: IntImp_ConstIsoparametric
        Param: TColStd_Array1OfReal
        UVap: math_Vector
        BornInf: math_Vector
        BornSup: math_Vector
        Tolerance: math_Vector

        Returns
        -------
        None

        """
        return _IntWalk.IntWalk_TheFunctionOfTheInt2S_ComputeParameters(self, *args)

    def Direction(self, *args) -> "gp_Dir":
        r"""
        No available documentation.

        Returns
        -------
        gp_Dir

        """
        return _IntWalk.IntWalk_TheFunctionOfTheInt2S_Direction(self, *args)

    def DirectionOnS1(self, *args) -> "gp_Dir2d":
        r"""
        No available documentation.

        Returns
        -------
        gp_Dir2d

        """
        return _IntWalk.IntWalk_TheFunctionOfTheInt2S_DirectionOnS1(self, *args)

    def DirectionOnS2(self, *args) -> "gp_Dir2d":
        r"""
        No available documentation.

        Returns
        -------
        gp_Dir2d

        """
        return _IntWalk.IntWalk_TheFunctionOfTheInt2S_DirectionOnS2(self, *args)

    def IsTangent(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Parameters
        ----------
        UVap: math_Vector
        Param: TColStd_Array1OfReal
        BestChoix: IntImp_ConstIsoparametric

        Returns
        -------
        bool

        """
        return _IntWalk.IntWalk_TheFunctionOfTheInt2S_IsTangent(self, *args)

    def Point(self, *args) -> "gp_Pnt":
        r"""
        No available documentation.

        Returns
        -------
        gp_Pnt

        """
        return _IntWalk.IntWalk_TheFunctionOfTheInt2S_Point(self, *args)

    def Root(self, *args) -> "Standard_Real":
        r"""
        Returns somme des fi*fi.

        Returns
        -------
        float

        """
        return _IntWalk.IntWalk_TheFunctionOfTheInt2S_Root(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _IntWalk.delete_IntWalk_TheFunctionOfTheInt2S

# Register IntWalk_TheFunctionOfTheInt2S in _IntWalk:
_IntWalk.IntWalk_TheFunctionOfTheInt2S_swigregister(IntWalk_TheFunctionOfTheInt2S)

class IntWalk_TheInt2S(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Compute the solution point with the close point.

        Parameters
        ----------
        Param: TColStd_Array1OfReal
        S1: Adaptor3d_HSurface
        S2: Adaptor3d_HSurface
        TolTangency: float

        Returns
        -------
        None
        Initialize the parameters to compute the solution point it 's possible to write to optimize: intimp_int2s inter(s1,s2,func,toltangency); math_functionsetroot rsnld(inter.function()); while ...{ param(1)=... param(2)=... param(3)=... inter.perform(param,rsnld); }.

        Parameters
        ----------
        S1: Adaptor3d_HSurface
        S2: Adaptor3d_HSurface
        TolTangency: float

        Returns
        -------
        None

        """
        _IntWalk.IntWalk_TheInt2S_swiginit(self, _IntWalk.new_IntWalk_TheInt2S(*args))

    def ChangePoint(self, *args) -> "IntSurf_PntOn2S &":
        r"""
        Return the intersection point which is enable for changing.

        Returns
        -------
        IntSurf_PntOn2S

        """
        return _IntWalk.IntWalk_TheInt2S_ChangePoint(self, *args)

    def Direction(self, *args) -> "gp_Dir const":
        r"""
        Returns the tangent at the intersection line.

        Returns
        -------
        gp_Dir

        """
        return _IntWalk.IntWalk_TheInt2S_Direction(self, *args)

    def DirectionOnS1(self, *args) -> "gp_Dir2d const":
        r"""
        Returns the tangent at the intersection line in the parametric space of the first surface.

        Returns
        -------
        gp_Dir2d

        """
        return _IntWalk.IntWalk_TheInt2S_DirectionOnS1(self, *args)

    def DirectionOnS2(self, *args) -> "gp_Dir2d const":
        r"""
        Returns the tangent at the intersection line in the parametric space of the second surface.

        Returns
        -------
        gp_Dir2d

        """
        return _IntWalk.IntWalk_TheInt2S_DirectionOnS2(self, *args)

    def Function(self, *args) -> "IntWalk_TheFunctionOfTheInt2S &":
        r"""
        Return the math function which is used to compute the intersection.

        Returns
        -------
        IntWalk_TheFunctionOfTheInt2S

        """
        return _IntWalk.IntWalk_TheInt2S_Function(self, *args)

    def IsDone(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the creation completed without failure.

        Returns
        -------
        bool

        """
        return _IntWalk.IntWalk_TheInt2S_IsDone(self, *args)

    def IsEmpty(self, *args) -> "Standard_Boolean":
        r"""
        Returns true when there is no solution to the problem.

        Returns
        -------
        bool

        """
        return _IntWalk.IntWalk_TheInt2S_IsEmpty(self, *args)

    def IsTangent(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the surfaces are tangent at the intersection point.

        Returns
        -------
        bool

        """
        return _IntWalk.IntWalk_TheInt2S_IsTangent(self, *args)

    def Perform(self, *args) -> "IntImp_ConstIsoparametric":
        r"""
        Returns the best constant isoparametric to find the next intersection's point +stores the solution point (the solution point is found with the close point to intersect the isoparametric with the other patch; the choice of the isoparametic is calculated).

        Parameters
        ----------
        Param: TColStd_Array1OfReal
        Rsnld: math_FunctionSetRoot

        Returns
        -------
        IntImp_ConstIsoparametric
        Returns the best constant isoparametric to find the next intersection's point +stores the solution point (the solution point is found with the close point to intersect the isoparametric with the other patch; the choice of the isoparametic is given by choixiso).

        Parameters
        ----------
        Param: TColStd_Array1OfReal
        Rsnld: math_FunctionSetRoot
        ChoixIso: IntImp_ConstIsoparametric

        Returns
        -------
        IntImp_ConstIsoparametric

        """
        return _IntWalk.IntWalk_TheInt2S_Perform(self, *args)

    def Point(self, *args) -> "IntSurf_PntOn2S const &":
        r"""
        Returns the intersection point.

        Returns
        -------
        IntSurf_PntOn2S

        """
        return _IntWalk.IntWalk_TheInt2S_Point(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _IntWalk.delete_IntWalk_TheInt2S

# Register IntWalk_TheInt2S in _IntWalk:
_IntWalk.IntWalk_TheInt2S_swigregister(IntWalk_TheInt2S)

class IntWalk_WalkingData(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr
    ustart = property(_IntWalk.IntWalk_WalkingData_ustart_get, _IntWalk.IntWalk_WalkingData_ustart_set)
    vstart = property(_IntWalk.IntWalk_WalkingData_vstart_get, _IntWalk.IntWalk_WalkingData_vstart_set)
    etat = property(_IntWalk.IntWalk_WalkingData_etat_get, _IntWalk.IntWalk_WalkingData_etat_set)

    __repr__ = _dumps_object


    def __init__(self):
        _IntWalk.IntWalk_WalkingData_swiginit(self, _IntWalk.new_IntWalk_WalkingData())
    __swig_destroy__ = _IntWalk.delete_IntWalk_WalkingData

# Register IntWalk_WalkingData in _IntWalk:
_IntWalk.IntWalk_WalkingData_swigregister(IntWalk_WalkingData)








from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.StepData import *
from OCC.Core.Interface import *
from OCC.Core.StepGeom import *


class RWStepGeom_RWAxis1Placement:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepGeom_Axis1Placement) -> None: ...
	def Share(self, ent: StepGeom_Axis1Placement, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepGeom_Axis1Placement) -> None: ...

class RWStepGeom_RWAxis2Placement2d:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepGeom_Axis2Placement2d) -> None: ...
	def Share(self, ent: StepGeom_Axis2Placement2d, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepGeom_Axis2Placement2d) -> None: ...

class RWStepGeom_RWAxis2Placement3d:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepGeom_Axis2Placement3d) -> None: ...
	def Share(self, ent: StepGeom_Axis2Placement3d, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepGeom_Axis2Placement3d) -> None: ...

class RWStepGeom_RWBSplineCurve:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepGeom_BSplineCurve) -> None: ...
	def Share(self, ent: StepGeom_BSplineCurve, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepGeom_BSplineCurve) -> None: ...

class RWStepGeom_RWBSplineCurveWithKnots:
	def __init__(self) -> None: ...
	def Check(self, ent: StepGeom_BSplineCurveWithKnots, shares: Interface_ShareTool, ach: Interface_Check) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepGeom_BSplineCurveWithKnots) -> None: ...
	def Share(self, ent: StepGeom_BSplineCurveWithKnots, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepGeom_BSplineCurveWithKnots) -> None: ...

class RWStepGeom_RWBSplineCurveWithKnotsAndRationalBSplineCurve:
	def __init__(self) -> None: ...
	def Check(self, ent: StepGeom_BSplineCurveWithKnotsAndRationalBSplineCurve, shares: Interface_ShareTool, ach: Interface_Check) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepGeom_BSplineCurveWithKnotsAndRationalBSplineCurve) -> None: ...
	def Share(self, ent: StepGeom_BSplineCurveWithKnotsAndRationalBSplineCurve, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepGeom_BSplineCurveWithKnotsAndRationalBSplineCurve) -> None: ...

class RWStepGeom_RWBSplineSurface:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepGeom_BSplineSurface) -> None: ...
	def Share(self, ent: StepGeom_BSplineSurface, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepGeom_BSplineSurface) -> None: ...

class RWStepGeom_RWBSplineSurfaceWithKnots:
	def __init__(self) -> None: ...
	def Check(self, ent: StepGeom_BSplineSurfaceWithKnots, shares: Interface_ShareTool, ach: Interface_Check) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepGeom_BSplineSurfaceWithKnots) -> None: ...
	def Share(self, ent: StepGeom_BSplineSurfaceWithKnots, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepGeom_BSplineSurfaceWithKnots) -> None: ...

class RWStepGeom_RWBSplineSurfaceWithKnotsAndRationalBSplineSurface:
	def __init__(self) -> None: ...
	def Check(self, ent: StepGeom_BSplineSurfaceWithKnotsAndRationalBSplineSurface, shares: Interface_ShareTool, ach: Interface_Check) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepGeom_BSplineSurfaceWithKnotsAndRationalBSplineSurface) -> None: ...
	def Share(self, ent: StepGeom_BSplineSurfaceWithKnotsAndRationalBSplineSurface, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepGeom_BSplineSurfaceWithKnotsAndRationalBSplineSurface) -> None: ...

class RWStepGeom_RWBezierCurve:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepGeom_BezierCurve) -> None: ...
	def Share(self, ent: StepGeom_BezierCurve, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepGeom_BezierCurve) -> None: ...

class RWStepGeom_RWBezierCurveAndRationalBSplineCurve:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepGeom_BezierCurveAndRationalBSplineCurve) -> None: ...
	def Share(self, ent: StepGeom_BezierCurveAndRationalBSplineCurve, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepGeom_BezierCurveAndRationalBSplineCurve) -> None: ...

class RWStepGeom_RWBezierSurface:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepGeom_BezierSurface) -> None: ...
	def Share(self, ent: StepGeom_BezierSurface, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepGeom_BezierSurface) -> None: ...

class RWStepGeom_RWBezierSurfaceAndRationalBSplineSurface:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepGeom_BezierSurfaceAndRationalBSplineSurface) -> None: ...
	def Share(self, ent: StepGeom_BezierSurfaceAndRationalBSplineSurface, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepGeom_BezierSurfaceAndRationalBSplineSurface) -> None: ...

class RWStepGeom_RWBoundaryCurve:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepGeom_BoundaryCurve) -> None: ...
	def Share(self, ent: StepGeom_BoundaryCurve, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepGeom_BoundaryCurve) -> None: ...

class RWStepGeom_RWBoundedCurve:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepGeom_BoundedCurve) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepGeom_BoundedCurve) -> None: ...

class RWStepGeom_RWBoundedSurface:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepGeom_BoundedSurface) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepGeom_BoundedSurface) -> None: ...

class RWStepGeom_RWCartesianPoint:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepGeom_CartesianPoint) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepGeom_CartesianPoint) -> None: ...

class RWStepGeom_RWCartesianTransformationOperator:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepGeom_CartesianTransformationOperator) -> None: ...
	def Share(self, ent: StepGeom_CartesianTransformationOperator, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepGeom_CartesianTransformationOperator) -> None: ...

class RWStepGeom_RWCartesianTransformationOperator3d:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepGeom_CartesianTransformationOperator3d) -> None: ...
	def Share(self, ent: StepGeom_CartesianTransformationOperator3d, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepGeom_CartesianTransformationOperator3d) -> None: ...

class RWStepGeom_RWCircle:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepGeom_Circle) -> None: ...
	def Share(self, ent: StepGeom_Circle, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepGeom_Circle) -> None: ...

class RWStepGeom_RWCompositeCurve:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepGeom_CompositeCurve) -> None: ...
	def Share(self, ent: StepGeom_CompositeCurve, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepGeom_CompositeCurve) -> None: ...

class RWStepGeom_RWCompositeCurveOnSurface:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepGeom_CompositeCurveOnSurface) -> None: ...
	def Share(self, ent: StepGeom_CompositeCurveOnSurface, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepGeom_CompositeCurveOnSurface) -> None: ...

class RWStepGeom_RWCompositeCurveSegment:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepGeom_CompositeCurveSegment) -> None: ...
	def Share(self, ent: StepGeom_CompositeCurveSegment, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepGeom_CompositeCurveSegment) -> None: ...

class RWStepGeom_RWConic:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepGeom_Conic) -> None: ...
	def Share(self, ent: StepGeom_Conic, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepGeom_Conic) -> None: ...

class RWStepGeom_RWConicalSurface:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepGeom_ConicalSurface) -> None: ...
	def Share(self, ent: StepGeom_ConicalSurface, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepGeom_ConicalSurface) -> None: ...

class RWStepGeom_RWCurve:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepGeom_Curve) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepGeom_Curve) -> None: ...

class RWStepGeom_RWCurveBoundedSurface:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepGeom_CurveBoundedSurface) -> None: ...
	def Share(self, ent: StepGeom_CurveBoundedSurface, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepGeom_CurveBoundedSurface) -> None: ...

class RWStepGeom_RWCurveReplica:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepGeom_CurveReplica) -> None: ...
	def Share(self, ent: StepGeom_CurveReplica, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepGeom_CurveReplica) -> None: ...

class RWStepGeom_RWCylindricalSurface:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepGeom_CylindricalSurface) -> None: ...
	def Share(self, ent: StepGeom_CylindricalSurface, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepGeom_CylindricalSurface) -> None: ...

class RWStepGeom_RWDegeneratePcurve:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepGeom_DegeneratePcurve) -> None: ...
	def Share(self, ent: StepGeom_DegeneratePcurve, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepGeom_DegeneratePcurve) -> None: ...

class RWStepGeom_RWDegenerateToroidalSurface:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepGeom_DegenerateToroidalSurface) -> None: ...
	def Share(self, ent: StepGeom_DegenerateToroidalSurface, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepGeom_DegenerateToroidalSurface) -> None: ...

class RWStepGeom_RWDirection:
	def __init__(self) -> None: ...
	def Check(self, ent: StepGeom_Direction, shares: Interface_ShareTool, ach: Interface_Check) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepGeom_Direction) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepGeom_Direction) -> None: ...

class RWStepGeom_RWElementarySurface:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepGeom_ElementarySurface) -> None: ...
	def Share(self, ent: StepGeom_ElementarySurface, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepGeom_ElementarySurface) -> None: ...

class RWStepGeom_RWEllipse:
	def __init__(self) -> None: ...
	def Check(self, ent: StepGeom_Ellipse, shares: Interface_ShareTool, ach: Interface_Check) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepGeom_Ellipse) -> None: ...
	def Share(self, ent: StepGeom_Ellipse, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepGeom_Ellipse) -> None: ...

class RWStepGeom_RWEvaluatedDegeneratePcurve:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepGeom_EvaluatedDegeneratePcurve) -> None: ...
	def Share(self, ent: StepGeom_EvaluatedDegeneratePcurve, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepGeom_EvaluatedDegeneratePcurve) -> None: ...

class RWStepGeom_RWGeomRepContextAndGlobUnitAssCtxAndGlobUncertaintyAssCtx:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepGeom_GeomRepContextAndGlobUnitAssCtxAndGlobUncertaintyAssCtx) -> None: ...
	def Share(self, ent: StepGeom_GeomRepContextAndGlobUnitAssCtxAndGlobUncertaintyAssCtx, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepGeom_GeomRepContextAndGlobUnitAssCtxAndGlobUncertaintyAssCtx) -> None: ...

class RWStepGeom_RWGeometricRepresentationContext:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepGeom_GeometricRepresentationContext) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepGeom_GeometricRepresentationContext) -> None: ...

class RWStepGeom_RWGeometricRepresentationContextAndGlobalUnitAssignedContext:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepGeom_GeometricRepresentationContextAndGlobalUnitAssignedContext) -> None: ...
	def Share(self, ent: StepGeom_GeometricRepresentationContextAndGlobalUnitAssignedContext, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepGeom_GeometricRepresentationContextAndGlobalUnitAssignedContext) -> None: ...

class RWStepGeom_RWGeometricRepresentationContextAndParametricRepresentationContext:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepGeom_GeometricRepresentationContextAndParametricRepresentationContext) -> None: ...
	def Share(self, ent: StepGeom_GeometricRepresentationContextAndParametricRepresentationContext, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepGeom_GeometricRepresentationContextAndParametricRepresentationContext) -> None: ...

class RWStepGeom_RWGeometricRepresentationItem:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepGeom_GeometricRepresentationItem) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepGeom_GeometricRepresentationItem) -> None: ...

class RWStepGeom_RWHyperbola:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepGeom_Hyperbola) -> None: ...
	def Share(self, ent: StepGeom_Hyperbola, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepGeom_Hyperbola) -> None: ...

class RWStepGeom_RWIntersectionCurve:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepGeom_IntersectionCurve) -> None: ...
	def Share(self, ent: StepGeom_IntersectionCurve, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepGeom_IntersectionCurve) -> None: ...

class RWStepGeom_RWLine:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepGeom_Line) -> None: ...
	def Share(self, ent: StepGeom_Line, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepGeom_Line) -> None: ...

class RWStepGeom_RWOffsetCurve3d:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepGeom_OffsetCurve3d) -> None: ...
	def Share(self, ent: StepGeom_OffsetCurve3d, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepGeom_OffsetCurve3d) -> None: ...

class RWStepGeom_RWOffsetSurface:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepGeom_OffsetSurface) -> None: ...
	def Share(self, ent: StepGeom_OffsetSurface, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepGeom_OffsetSurface) -> None: ...

class RWStepGeom_RWOrientedSurface:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepGeom_OrientedSurface) -> None: ...
	def Share(self, ent: StepGeom_OrientedSurface, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepGeom_OrientedSurface) -> None: ...

class RWStepGeom_RWOuterBoundaryCurve:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepGeom_OuterBoundaryCurve) -> None: ...
	def Share(self, ent: StepGeom_OuterBoundaryCurve, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepGeom_OuterBoundaryCurve) -> None: ...

class RWStepGeom_RWParabola:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepGeom_Parabola) -> None: ...
	def Share(self, ent: StepGeom_Parabola, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepGeom_Parabola) -> None: ...

class RWStepGeom_RWPcurve:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepGeom_Pcurve) -> None: ...
	def Share(self, ent: StepGeom_Pcurve, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepGeom_Pcurve) -> None: ...

class RWStepGeom_RWPlacement:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepGeom_Placement) -> None: ...
	def Share(self, ent: StepGeom_Placement, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepGeom_Placement) -> None: ...

class RWStepGeom_RWPlane:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepGeom_Plane) -> None: ...
	def Share(self, ent: StepGeom_Plane, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepGeom_Plane) -> None: ...

class RWStepGeom_RWPoint:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepGeom_Point) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepGeom_Point) -> None: ...

class RWStepGeom_RWPointOnCurve:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepGeom_PointOnCurve) -> None: ...
	def Share(self, ent: StepGeom_PointOnCurve, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepGeom_PointOnCurve) -> None: ...

class RWStepGeom_RWPointOnSurface:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepGeom_PointOnSurface) -> None: ...
	def Share(self, ent: StepGeom_PointOnSurface, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepGeom_PointOnSurface) -> None: ...

class RWStepGeom_RWPointReplica:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepGeom_PointReplica) -> None: ...
	def Share(self, ent: StepGeom_PointReplica, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepGeom_PointReplica) -> None: ...

class RWStepGeom_RWPolyline:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepGeom_Polyline) -> None: ...
	def Share(self, ent: StepGeom_Polyline, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepGeom_Polyline) -> None: ...

class RWStepGeom_RWQuasiUniformCurve:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepGeom_QuasiUniformCurve) -> None: ...
	def Share(self, ent: StepGeom_QuasiUniformCurve, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepGeom_QuasiUniformCurve) -> None: ...

class RWStepGeom_RWQuasiUniformCurveAndRationalBSplineCurve:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepGeom_QuasiUniformCurveAndRationalBSplineCurve) -> None: ...
	def Share(self, ent: StepGeom_QuasiUniformCurveAndRationalBSplineCurve, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepGeom_QuasiUniformCurveAndRationalBSplineCurve) -> None: ...

class RWStepGeom_RWQuasiUniformSurface:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepGeom_QuasiUniformSurface) -> None: ...
	def Share(self, ent: StepGeom_QuasiUniformSurface, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepGeom_QuasiUniformSurface) -> None: ...

class RWStepGeom_RWQuasiUniformSurfaceAndRationalBSplineSurface:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepGeom_QuasiUniformSurfaceAndRationalBSplineSurface) -> None: ...
	def Share(self, ent: StepGeom_QuasiUniformSurfaceAndRationalBSplineSurface, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepGeom_QuasiUniformSurfaceAndRationalBSplineSurface) -> None: ...

class RWStepGeom_RWRationalBSplineCurve:
	def __init__(self) -> None: ...
	def Check(self, ent: StepGeom_RationalBSplineCurve, shares: Interface_ShareTool, ach: Interface_Check) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepGeom_RationalBSplineCurve) -> None: ...
	def Share(self, ent: StepGeom_RationalBSplineCurve, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepGeom_RationalBSplineCurve) -> None: ...

class RWStepGeom_RWRationalBSplineSurface:
	def __init__(self) -> None: ...
	def Check(self, ent: StepGeom_RationalBSplineSurface, shares: Interface_ShareTool, ach: Interface_Check) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepGeom_RationalBSplineSurface) -> None: ...
	def Share(self, ent: StepGeom_RationalBSplineSurface, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepGeom_RationalBSplineSurface) -> None: ...

class RWStepGeom_RWRectangularCompositeSurface:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepGeom_RectangularCompositeSurface) -> None: ...
	def Share(self, ent: StepGeom_RectangularCompositeSurface, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepGeom_RectangularCompositeSurface) -> None: ...

class RWStepGeom_RWRectangularTrimmedSurface:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepGeom_RectangularTrimmedSurface) -> None: ...
	def Share(self, ent: StepGeom_RectangularTrimmedSurface, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepGeom_RectangularTrimmedSurface) -> None: ...

class RWStepGeom_RWReparametrisedCompositeCurveSegment:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepGeom_ReparametrisedCompositeCurveSegment) -> None: ...
	def Share(self, ent: StepGeom_ReparametrisedCompositeCurveSegment, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepGeom_ReparametrisedCompositeCurveSegment) -> None: ...

class RWStepGeom_RWSeamCurve:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepGeom_SeamCurve) -> None: ...
	def Share(self, ent: StepGeom_SeamCurve, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepGeom_SeamCurve) -> None: ...

class RWStepGeom_RWSphericalSurface:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepGeom_SphericalSurface) -> None: ...
	def Share(self, ent: StepGeom_SphericalSurface, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepGeom_SphericalSurface) -> None: ...

class RWStepGeom_RWSurface:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepGeom_Surface) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepGeom_Surface) -> None: ...

class RWStepGeom_RWSurfaceCurve:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepGeom_SurfaceCurve) -> None: ...
	def Share(self, ent: StepGeom_SurfaceCurve, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepGeom_SurfaceCurve) -> None: ...

class RWStepGeom_RWSurfaceCurveAndBoundedCurve:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepGeom_SurfaceCurveAndBoundedCurve) -> None: ...
	def Share(self, ent: StepGeom_SurfaceCurveAndBoundedCurve, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepGeom_SurfaceCurveAndBoundedCurve) -> None: ...

class RWStepGeom_RWSurfaceOfLinearExtrusion:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepGeom_SurfaceOfLinearExtrusion) -> None: ...
	def Share(self, ent: StepGeom_SurfaceOfLinearExtrusion, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepGeom_SurfaceOfLinearExtrusion) -> None: ...

class RWStepGeom_RWSurfaceOfRevolution:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepGeom_SurfaceOfRevolution) -> None: ...
	def Share(self, ent: StepGeom_SurfaceOfRevolution, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepGeom_SurfaceOfRevolution) -> None: ...

class RWStepGeom_RWSurfacePatch:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepGeom_SurfacePatch) -> None: ...
	def Share(self, ent: StepGeom_SurfacePatch, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepGeom_SurfacePatch) -> None: ...

class RWStepGeom_RWSurfaceReplica:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepGeom_SurfaceReplica) -> None: ...
	def Share(self, ent: StepGeom_SurfaceReplica, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepGeom_SurfaceReplica) -> None: ...

class RWStepGeom_RWSweptSurface:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepGeom_SweptSurface) -> None: ...
	def Share(self, ent: StepGeom_SweptSurface, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepGeom_SweptSurface) -> None: ...

class RWStepGeom_RWToroidalSurface:
	def __init__(self) -> None: ...
	def Check(self, ent: StepGeom_ToroidalSurface, shares: Interface_ShareTool, ach: Interface_Check) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepGeom_ToroidalSurface) -> None: ...
	def Share(self, ent: StepGeom_ToroidalSurface, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepGeom_ToroidalSurface) -> None: ...

class RWStepGeom_RWTrimmedCurve:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepGeom_TrimmedCurve) -> None: ...
	def Share(self, ent: StepGeom_TrimmedCurve, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepGeom_TrimmedCurve) -> None: ...

class RWStepGeom_RWUniformCurve:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepGeom_UniformCurve) -> None: ...
	def Share(self, ent: StepGeom_UniformCurve, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepGeom_UniformCurve) -> None: ...

class RWStepGeom_RWUniformCurveAndRationalBSplineCurve:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepGeom_UniformCurveAndRationalBSplineCurve) -> None: ...
	def Share(self, ent: StepGeom_UniformCurveAndRationalBSplineCurve, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepGeom_UniformCurveAndRationalBSplineCurve) -> None: ...

class RWStepGeom_RWUniformSurface:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepGeom_UniformSurface) -> None: ...
	def Share(self, ent: StepGeom_UniformSurface, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepGeom_UniformSurface) -> None: ...

class RWStepGeom_RWUniformSurfaceAndRationalBSplineSurface:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepGeom_UniformSurfaceAndRationalBSplineSurface) -> None: ...
	def Share(self, ent: StepGeom_UniformSurfaceAndRationalBSplineSurface, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepGeom_UniformSurfaceAndRationalBSplineSurface) -> None: ...

class RWStepGeom_RWVector:
	def __init__(self) -> None: ...
	def Check(self, ent: StepGeom_Vector, shares: Interface_ShareTool, ach: Interface_Check) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepGeom_Vector) -> None: ...
	def Share(self, ent: StepGeom_Vector, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepGeom_Vector) -> None: ...

# harray1 classes
# harray2 classes
# hsequence classes

